@@ -6,10 +6,10 @@ use 5.016;
 use warnings;
 use utf8;
 
-our $VERSION = 0.009;
+our $VERSION = 1.000;
 
 use IP::Geolocation::MMDB::Metadata;
-use Math::BigInt 1.999811;
+use Math::BigInt 1.999806;
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -31,10 +31,12 @@ sub getcc {
   my $country_code;
 
   my $data = $self->record_for_address($ip_address);
-  if (exists $data->{country}) {
-    my $country = $data->{country};
-    if (exists $country->{iso_code}) {
-      $country_code = $country->{iso_code};
+  if (ref $data eq 'HASH') {
+    if (exists $data->{country}) {
+      my $country = $data->{country};
+      if (exists $country->{iso_code}) {
+        $country_code = $country->{iso_code};
+      }
     }
   }
 
@@ -66,7 +68,7 @@ IP::Geolocation::MMDB - Read MaxMind DB files
 
 =head1 VERSION
 
-version 0.009
+version 1.000
 
 =head1 SYNOPSIS
 
@@ -78,8 +80,8 @@ version 0.009
 
 =head1 DESCRIPTION
 
-A Perl module that reads MaxMind DB files and maps IP addresses to two-letter
-country codes such as "DE", "FR" and "US".
+A Perl module that reads MaxMind DB files and maps IP addresses to location
+information such as country and city names.
 
 =head1 SUBROUTINES/METHODS
 
@@ -105,7 +107,29 @@ the IP address or the undefined value.  Dies if the address is not a valid IP
 address.
 
 The returned data is usually a hash reference but could also be a an array
-reference or a scalar for custom databases.
+reference or a scalar for custom databases.  Here's an example from an IP to
+city database:
+
+  {
+    city => {
+      geoname_id => 2950159,
+      names      => {
+        en => "Berlin"
+      }
+    },
+    country => {
+      geoname_id => 2921044,
+      iso_code   => "DE",
+      names      => {
+        en => "Germany",
+        fr => "Allemagne"
+      }
+    },
+    location => {
+      latitude  => 52.524,
+      longitude => 13.411
+    }
+  }
 
 =head2 iterate_search_tree
 
@@ -125,8 +149,8 @@ data record and node in the tree.  Both callbacks are optional.
 The data callback is called with a numeric IP address as a L<Math::BigInt>
 object, a network prefix length and the data associated with the network.
 
-The node callback is called with a node number and the children's node
-numbers.
+The node callback is called with the node's number in the tree and the
+children's node numbers.
 
 =head2 metadata
 
@@ -144,6 +168,10 @@ Returns the libmaxminddb version.
 
 =over
 
+=item B<< The "file" parameter is mandatory >>
+
+The constructor was called without a database filename.
+
 =item B<< Error opening database file >>
 
 The database file could not be read.
@@ -173,6 +201,10 @@ Either an invalid node was looked up or the database is corrupt.
 
 An unknown record type was found in the database.
 
+=item B<< Invalid depth when reading node >>
+
+An error occurred while traversing the search tree.
+
 =back
 
 =head1 CONFIGURATION AND ENVIRONMENT
@@ -182,11 +214,11 @@ None.
 =head1 DEPENDENCIES
 
 Requires L<Alien::libmaxminddb> from CPAN.  On Windows, L<Alien::MSYS> needs
-to be installed.  Requires L<Math::BigInt> version 1.999807, which is
-distributed with Perl 5.28 and newer.
+to be installed.  Requires L<Math::BigInt> version 1.999806, which is
+distributed with Perl 5.26 and newer.
 
-Requires an IP to country database in the MaxMind DB file format from
-L<DP-IP.com|https://db-ip.com/> or L<MaxMind|https://www.maxmind.com/>.
+Requires an IP to country, city or ASN database in the MaxMind DB file format
+from L<MaxMind|https://www.maxmind.com/> or L<DP-IP.com|https://db-ip.com/>.
 
 =head1 INCOMPATIBILITIES
 
